@@ -6,7 +6,7 @@ use POSIX qw/sysconf _SC_PAGESIZE/;
 use Test::Builder;
 use Test::More;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use base qw(Exporter);
 
@@ -20,7 +20,7 @@ Test::NoLeaks - Memory and file descriptor leak detector
 
 =head1 VERSION
 
-0.03
+0.04
 
 =head1 SYNOPSYS
 
@@ -115,7 +115,7 @@ pass, then C<1024> passes should be specified.
 In general, the more passes are specified, the more chance to
 detect possible leaks.
 
-It is good idea to initally define C<passess> to some large number,
+It is good idea to initally define C<passes> to some large number,
 e.g. C<10_000> to be sure, that the suspicious code leaks, but then
 decrease to some smaller number, enough to produce test fail report,
 i.e. enough to produces 3-5 memory hits (additional pages allocations).
@@ -144,7 +144,7 @@ Even if your code has no leaks, it might cause perl interpreter
 allocate additional memory pages, e.g. due to memory fragmentation.
 Those allocations are legal, and should not be treated as leaks.
 
-Use this B<only >when memory leaks are already fixed, but there
+Use this B<only> when memory leaks are already fixed, but there
 are still false leak reports from C<test_leak>. This value expected
 to be small enough, i.e. C<1> or C<2>. For additional assurance, please,
 increase C<passes> value, if C<tolarate_hits> is non-zero.
@@ -193,6 +193,21 @@ So, the code under test should look much more production like, i.e.
 That way web-application is created only once, and leaks will be tracked
 on request-related code.
 
+Anyway, C<might_leak> still wrong, because it unintentionally leaks due to
+use of direct or indirect L<Test::More> functions, like C<ok> or
+C<post_ok>. They should not be used; if you still need to assert, that
+C<might_leak> works propertly, you can use C<BAIL_OUT> subroutine,
+to cancel any further testing, e.g.
+
+  sub might_leak {
+    my $got = some_function_might_leak;
+    my $expected = "some_value";
+    BAIL_OUT('some_function_might_leak does not work propertly!')
+      unless $got eq $expected;
+  }
+
+
+
 Please, B<do not> use C<test_noleaks> more then once per test file. Consider
 the following example:
 
@@ -229,6 +244,9 @@ send PR.
 
 =back
 
+=head1 SEE ALSO
+
+L<Test::MemoryGrowth>
 
 =cut
 
